@@ -50,13 +50,12 @@ var (
 )
 
 const (
-	runCmdsQuestion   = "Would you like to run these Git commands"
+	runCmdsQuestion   = "Would you like to run these Git commands?"
 	gitCmd            = "git"
 	gitCmdAPIPath     = "ai/llm/git_command"
 	spinnerText       = "Generating Git commands..."
-	aiResponseErr     = "Error: AI response has not been generated correctly"
-	apiUnreachableErr = "Error: API is unreachable"
-	experimentMsg     = "AI generated these responses. Leave feedback: https://gitlab.com/gitlab-org/gitlab/-/issues/409636\n"
+	aiResponseErr     = "Error: AI response has not been generated correctly."
+	apiUnreachableErr = "Error: API is unreachable."
 )
 
 func NewCmdAsk(f *cmdutils.Factory) *cobra.Command {
@@ -67,17 +66,13 @@ func NewCmdAsk(f *cmdutils.Factory) *cobra.Command {
 
 	duoAskCmd := &cobra.Command{
 		Use:   "ask <prompt>",
-		Short: "Generate Git commands from natural language (Experimental).",
+		Short: "Generate Git commands from natural language.",
 		Long: heredoc.Doc(`
 			Generate Git commands from natural language.
-
-			This experimental feature converts natural language descriptions into
-			executable Git commands.
-
-			We'd love your feedback in [issue 409636](https://gitlab.com/gitlab-org/gitlab/-/issues/409636).
 		`),
 		Example: heredoc.Doc(`
 			$ glab duo ask list last 10 commit titles
+
 			# => A list of Git commands to show the titles of the latest 10 commits with an explanation and an option to execute the commands.
 		`),
 		RunE: func(cmd *cobra.Command, args []string) error {
@@ -107,7 +102,7 @@ func NewCmdAsk(f *cmdutils.Factory) *cobra.Command {
 		},
 	}
 
-	duoAskCmd.Flags().BoolVarP(&opts.Git, "git", "", true, "Ask a question about git")
+	duoAskCmd.Flags().BoolVarP(&opts.Git, "git", "", true, "Ask a question about Git.")
 
 	return duoAskCmd
 }
@@ -118,13 +113,13 @@ func (opts *opts) Result() (*result, error) {
 
 	client, err := opts.HttpClient()
 	if err != nil {
-		return nil, cmdutils.WrapError(err, "failed to get http client")
+		return nil, cmdutils.WrapError(err, "failed to get HTTP client.")
 	}
 
 	body := request{Prompt: opts.Prompt, Model: vertexAI}
 	request, err := client.NewRequest(http.MethodPost, gitCmdAPIPath, body, nil)
 	if err != nil {
-		return nil, cmdutils.WrapError(err, "failed to create a request")
+		return nil, cmdutils.WrapError(err, "failed to create a request.")
 	}
 
 	var r response
@@ -153,9 +148,6 @@ func (opts *opts) Result() (*result, error) {
 func (opts *opts) displayResult(result *result) {
 	color := opts.IO.Color()
 
-	opts.IO.LogInfo(color.Bold("Experiment:"))
-	opts.IO.LogInfo(color.Gray(experimentMsg))
-
 	opts.IO.LogInfo(color.Bold("Commands:\n"))
 
 	for _, cmd := range result.Commands {
